@@ -27,7 +27,7 @@ class ftpUtil:
         try:
             ftype = os.path.splitext(local_path)[-1]
             if ftype.upper()=='.MP4' or ftype.upper()=='.WMV':
-                clip=VideoFileClip()
+                clip=VideoFileClip(local_path)
                 duration=clip.duration
                 duration = 0
             else:
