@@ -64,11 +64,11 @@ class mysqlUtil:
         return None
 
     #添加上传文件记录
-    def sftp_file_ins(self,filename,url,stud,desc):
+    def sftp_file_ins(self,filename,url,stud,desc,fsize,duration,ftype):
         try:
-            df = pd.DataFrame(columns=['filename','url','stud','desc'])
+            df = pd.DataFrame(columns=['filename','url','stud','desc','fsize','duration','ftype'])
             # print(df)
-            row1=pd.DataFrame({'filename':filename,'url':url,'stud':stud,'desc':desc}, index=[1])
+            row1=pd.DataFrame({'filename':filename,'url':url,'stud':stud,'desc':desc,'fsize':fsize,'duration':duration,'ftype':ftype}, index=[1])
             # print(row1)
             # df=df.append(row1,ignore_index=True)
             df = pd.concat([df, row1], ignore_index=True)  # append过时，改用concat
